summaryrefslogtreecommitdiffstats
path: root/buildtools/autotools/autoprojectwidget.h
diff options
context:
space:
mode:
Diffstat (limited to 'buildtools/autotools/autoprojectwidget.h')
-rw-r--r--buildtools/autotools/autoprojectwidget.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/buildtools/autotools/autoprojectwidget.h b/buildtools/autotools/autoprojectwidget.h
index 7d21fd55..554a90f7 100644
--- a/buildtools/autotools/autoprojectwidget.h
+++ b/buildtools/autotools/autoprojectwidget.h
@@ -133,13 +133,13 @@ public:
SubprojectItem* selectedSubproject();
/**
* Creates a TargetItem instance without a tqparent item.
*/
TargetItem *createTargetItem( const TQString &name,
const TQString &prefix, const TQString &primary,
bool take = true );
/**
* Creates a FileItem instance without a tqparent item.
*/
FileItem *createFileItem( const TQString &name, SubprojectItem *subproject );
@@ -203,8 +203,8 @@ public slots:
void slotOverviewSelectionChanged( TQListViewItem *item );
protected:
- void initOverview ( TQWidget* tqparent );
- void initDetailview ( TQWidget* tqparent );
+ void initOverview ( TQWidget* parent );
+ void initDetailview ( TQWidget* parent );
void initActions ();
virtual void focusInEvent( TQFocusEvent *e );
@@ -133,13 +133,13 @@ public:
SubprojectItem* selectedSubproject();
/**
- * Creates a TargetItem instance without a tqparent item.
+ * Creates a TargetItem instance without a parent item.
*/
TargetItem *createTargetItem( const TQString &name,
@@ -133,13 +133,13 @@ public:
bool take = true );
/**
- * Creates a FileItem instance without a tqparent item.
+ * Creates a FileItem instance without a parent item.
*/
FileItem *createFileItem( const TQString &name, SubprojectItem *subproject );